Index: extensions/LLGBO2/include/manage_header.php
===================================================================
--- extensions/LLGBO2/include/manage_header.php	(revision 29048)
+++ extensions/LLGBO2/include/manage_header.php	(revision 29049)
@@ -3,28 +3,29 @@
 /*      LLGBO Manage header 					   */
 //----------------------------------------------------
+global $template,$conf;
+$page_name = script_basename();
 if (!isset($page_name)) {$page_name ='index';}
 if ($conf['LLGBO2']['manageheader']) 
 	{$no_header = false;
-	$input= $_SERVER['PHP_SELF'];
-	if ($conf['question_mark_in_urls'] == true)
-		{	foreach($_GET as $cle  =>$valeur) 
-			{$input= $input.$cle ;}
-	} 
-	 
-	if  ( strpos( $input,'index') == true )
-	{	foreach($conf['LLGBO2']['HD-dispheader'] as $cle  => $valeur) 
-			{ if ($valeur  == false) {
-					if($cle == 'home' ) {$cle = 'index.php';} 
-					if (strpos( $input, $cle) == true ) 
-						{$no_header = true;}
-					}
-			}
-	} 
-	 else 
-	{	 
-		 if (isset($conf['LLGBO2']['HD-dispheader'][$page_name]) and ($conf['LLGBO2']['HD-dispheader'][$page_name] == false) ) {$no_header = true;} 
-	}  
-	 if ($no_header == true)
-	{$template->append('head_elements','<!-- llgbo -->'."\n".'<STYLE type="text/css">'."\n".'#theHeader{display: none}'."\n".'header_msgs {position:static}'."\n".'</STYLE>');}
+		$input= $_SERVER['PHP_SELF'];
+		if ($conf['question_mark_in_urls'] == true)
+			{	foreach($_GET as $cle  =>$valeur) 
+				{$input= $input.$cle ;}
+		} 
+		 
+		if  ( strpos( $input,'index') == true )
+		{	foreach($conf['LLGBO2']['HD-dispheader'] as $cle  => $valeur) 
+				{ if ($valeur  == false) {
+						if($cle == 'home' ) {$cle = 'index.php';} 
+						if (strpos( $input, $cle) == true ) 
+							{$no_header = true;}
+						}
+				}
+		} 
+		 else 
+		{	if (isset($conf['LLGBO2']['HD-dispheader'][$page_name]) and ($conf['LLGBO2']['HD-dispheader'][$page_name] == false) ) {$no_header = true;} 
+		}  
+	if ($no_header == true)
+		{$template->append('head_elements','<!-- llgbo no header-->'."\n".'<STYLE type="text/css">'."\n".'#theHeader{display: none}'."\n".'header_msgs {position:static}'."\n".'</STYLE>');}
 }	
 ?>
Index: extensions/LLGBO2/js/jquery_llgboframeresize.js
===================================================================
--- extensions/LLGBO2/js/jquery_llgboframeresize.js	(revision 29048)
+++ extensions/LLGBO2/js/jquery_llgboframeresize.js	(revision 29049)
@@ -1,22 +1,30 @@
 // LLGBO frame resize 
-jQuery(document).ready(function(jQuery){ 
-	 jQuery("#theMainImage").load(function(){LlgboFr_Resize();});	
-	jQuery(window).resize(function(){ LlgboFr_Resize(); }); 
-});
-var LlgboFr_Resize = function () {
-	var Elmgbo = jQuery("#llgbo0");
-       if (Elmgbo.size() > 0) 
-	 {	var MainImg = jQuery("#theMainImage");
-	       if (jQuery("#theMainImage").size() > 0)
-		   {	var nImgH = parseInt(MainImg.height() ); 
-				var nImgW = parseInt(MainImg.width() );
-				var FrLstBdr = 0; var frbdr=0;
-				jQuery(".llgboFR").each(function(){ 
-					 frbdr = parseInt(jQuery(this).css('border-top-width'));
-						FrLstBdr = (frbdr * 2)+FrLstBdr; 
-					});			
+jQuery(document).ready(	function(){
+		function LlgboFr_Resize()
+		 {	var Elmgbo = jQuery("#llgbo0");
+			if (Elmgbo.size() > 0) 
+			 {	var MainImg = jQuery("#theMainImage");
+				if (MainImg.size() > 0)
+				   {	var nImgH = parseInt(MainImg.height() ); 
+						var nImgW = parseInt(MainImg.width() );
+						var FrLstBdr = 0; var frbdr=0;
+						jQuery(".llgboFR").each(function(){ 
+							 frbdr = parseInt(jQuery(this).css('border-top-width'));
+								FrLstBdr = (frbdr * 2)+FrLstBdr; 
+							});
+					}		
 				Elmgbo.width (nImgW + FrLstBdr) ;
 				Elmgbo.height (nImgH + FrLstBdr) ; 
-			}
-	}		
-}
+			}		
+		}
+	LlgboFr_Resize();
+	
+	jQuery(window).resize(function(){ 
+				LlgboFr_Resize(); });
+			
+	jQuery("#theMainImage").load(function(){
+				LlgboFr_Resize();});
+ });
+
+
+
Index: extensions/LLGBO2/main.inc.php
===================================================================
--- extensions/LLGBO2/main.inc.php	(revision 29048)
+++ extensions/LLGBO2/main.inc.php	(revision 29049)
@@ -8,22 +8,8 @@
 Description:  Display thumbnail under button. Add navigation on picture look like GBo Gallery 
 Add a border around  picture ......
-	2.4.A Beta1 Compliance Piwigo 2.4 + jquery
-	2.4.B beta 2 Compliance with Theme Stripped and plugin Piwishak  
-	2.4.C First version for official Piwigo 2.4
-	2.4.D Compliance with Theme Simple + fix bug on option
-	2.4.F Improvement on frame management first size
-		  Frame available on SlideShow.	
-	2.4.G Compliance with plugin RV MAP & EARTH
--- 05-05-2013	
-	2.5.A Fix bug  back to default values after  deactivates / reactivates actions 
-	2.5.B Fix bug  back to default values after  deactivates / reactivates actions (with API)
-	2.5.C Fix bug  notice with $lang
--- 30-12-2013   
-		2.6.A Compliance Piwigo 2.6	and automatic size
--- 01-07-2014   
+	-- 01-07-2014   
 		2.7.A Compliance Piwigo 2.7	new administration management
  */
 if (!defined('PHPWG_ROOT_PATH')) die('Hacking attempt!');
-
 
 // +-----------------------------------------------------------------------+
@@ -55,6 +41,4 @@
 	$conf['LLGBO2'] =  safe_unserialize($conf['LLGBO2_Settings']);
 } 
-
-
 /******************************************************************/
 /*       ALWAYS      DISPLAY      METADATA */
@@ -70,6 +54,6 @@
 			{  pwg_set_session_var('show_metadata', 1 );	 }
 		}
-}// --------------- end begin picture 
-
+}
+// --------------- end begin picture 
 /******************************************************************/
 //      MANAGE     BEGIN          H E A D E R 
@@ -86,10 +70,6 @@
 function llgbo_endHeader()
 /******************************************************************/
-{global $template,$conf;
-	$page_name = script_basename();
-	include_once(LLGBO_PATH.'include/manage_header.php');
+{include_once(LLGBO_PATH.'include/manage_header.php');
 }  // --------------- end header 
-
-
 /******************************************************************/
 //* IMPROVE FUNCTIONNALITIES --> PICTURE.TPL
@@ -97,142 +77,41 @@
 function  llgbo_EndPicture()
 /******************************************************************/
-{ global $template,$conf,$page,$lang;
-	//----------------------------------------------------	 
-	/*       HTML End  frame   on Picture.tpl       */
-	//----------------------------------------------------	
-			
-	If (($conf['LLGBO2']['frame'])    //Frame
-		 and (!empty($conf['LLGBO2']['rendercontent']))	)// $content ok for update
-		{ 	$target = 'picture';
-			if ($page['slideshow'] and $conf['light_slideshow'])
-			{ $target = 'slideshow';}
-			$template->set_prefilter($target, 'LLGBO_prefilter_Picture_Frame');
-		 //$PictSizeWH is not already defined by auto_size 	
-		  $current= $template->get_template_vars('current'); 
-		  if (empty($conf['LLGBO2']['PictSizeWH']))
-				{$conf['LLGBO2']['PictSizeWH'] =  $current['selected_derivative']->get_size();}
-			$PictSizeWH = $conf['LLGBO2']['PictSizeWH'];		
-			$frame_width  = $PictSizeWH[0];
-			$frame_height = $PictSizeWH[1];
-			$frame_begin ='';
-			 foreach ($conf['LLGBO2']['FR-sizes'] as $cle  => $value) 
-				{ if ( $value > 0)	// boder value > 0	
-					 {	$frame_width = $frame_width + ( 2 * $value);				 
-						$frame_height = $frame_height + ( 2* $value); 
-						$frame_begin = '<div class="llgboFR" style="border:'.$value.'px solid '.$conf['LLGBO2']['FR-colors'][$cle].'">'."\n".$frame_begin;
-						} 
-				}
-				
-			$frame_size = "\n".'<!-- Begin LLGBO frame -->'."\n".'<div   id="llgbo0" class="llgbo" style="border:0 ;width:'.$frame_width.'px; height:'.$frame_height.'px;">';
-			$template->append('llgbo', array(
-				 'FRAME_SIZE' => $frame_size ,
-				 'FRAME_BEGIN' => $frame_begin), true); 
-				 
-		If ($conf['LLGBO2']['titleframe'] )  
-			 {  $template->append('llgbo', array(
-					 'TITLE_FRAME_COLOR' => $conf['LLGBO2']['FR-titlecolor'],
-					 'TITLE_FRAME' => $current['name'] ), true);
-				$template->assign('SHOW_PICTURE_NAME_ON_TITLE' , false); 
-				}			
-		} //--------------- end frame
-		
-	
-	// ---- Metadata ----------	
-	$ext = get_extension($current['path']);
-	if (!in_array($ext, $conf['picture_ext'])) 
-		{$lang['Show file metadata'] =  'No Metadata';}
-		else
-		{if ($conf['show_exif']) // No exif ?
-			{$meta = "";
-			$u_metadata = $template->get_template_vars('U_METADATA');
-			$swt = "";
-			 If ($conf['LLGBO2']['exifunderbt'])  // exif under bt
-				{  $metadata = $template->get_template_vars('metadata');
-				if (is_array($metadata)) 
-				  {  if (isset($metadata[0]) and is_array($metadata[0]))
-						{foreach($metadata[0] as $cle =>$tableau)
-							{ if(is_array($tableau))
-							 {   foreach($tableau as $cle=>$valeur)
-								{   $swt= $swt.$cle.' : '.$valeur.'||';
-									$meta = 1;} }	}
-							if  ( pwg_get_session_var('show_metadata') == 1 )
-							{  	$lang['Show file metadata'] =  'EXIF Metadata';
-								 if (isset($metadata[0] ['TITLE'])) // advanced meta
-								{$lang['Show file metadata']	= $metadata [0] ['TITLE'];}
-								if ($meta  != 1 ) {$lang['Show file metadata'] =  'No Metadata';}
-							}
-							$template->assign( 'U_METADATA', $u_metadata.'" title="'.$lang['Show file metadata']."||".$swt);
-							unset( $metadata[0]); 
-							 $template->Clear_assign('metadata');// hide original metadata	
-							 $template->assign('metadata',$metadata);} //  original metadata item > 0	
-				  }
-				  else
-				  {if  ( pwg_get_session_var('show_metadata') == 1 )
-				  {$lang['Show file metadata'] =  'No Metadata';
-				   $template->assign( 'U_METADATA', $u_metadata.'" title="'.$lang['Show file metadata']);}
-				   }
-				} 
+{ global $template,$conf,$lang;
+	if	(!empty($conf['LLGBO2']['is-picture']))	
+	 { 	// ---- Metadata ----------	
+		if ($conf['LLGBO2']['exifunderbt'])  // exif under bt
+				{  	$metadata = $template->get_template_vars('metadata');
+				   if (is_array($metadata[0]))
+						{
+						if ($metadata [0] ['TITLE'] == $lang['EXIF Metadata']	 )  // only exif are displayed under buton
+							{$u_metadata = $template->get_template_vars('U_METADATA');
+								$swt = '';	
+								foreach($metadata[0]['lines'] as $cle=>$valeur){$swt= $swt.$cle.' : '.$valeur.'||';} 
+								if  ( pwg_get_session_var('show_metadata') == 1 )
+ 									{ $lang['Show file metadata'] = $metadata [0] ['TITLE'];} 						
+								$template->assign( 'U_METADATA',$u_metadata.'" title="'.$lang['Show file metadata']."||".$swt);
+								unset( $metadata[0]); 
+								$template->Clear_assign('metadata');// hide all original metadata	
+								$template->assign('metadata',$metadata); }//  always display  metadata elem > 0
+						} 	
+				else
+					{if  (( pwg_get_session_var('show_metadata') == 1 ) and (!is_array($metadata)))
+							{$template->Clear_assign( 'U_METADATA');} 
+					}
 			}
-		}
-	// --------------------------------------
-	// Add llgbo requirement to ELEMENT_CONTENT
-	// --------------------------------------
-	$template->set_filenames( array('llgbo_content'=> dirname(__FILE__).'/template/llgbo_content.tpl') );
-	$template->concat('picture', $template->parse('llgbo_content', true));
+		// --------------------------------------
+		// Add llgbo requirement to ELEMENT_CONTENT
+		// --------------------------------------
+		$template->set_filenames( array('llgbo_content'=> dirname(__FILE__).'/template/llgbo_content.tpl') );
+		$template->concat('picture', $template->parse('llgbo_content', true));
+	}	
 } 
-
-
 
 /******************************************************************
 			------   MANAGE PICTURE PAGE                --------------     
  ******************************************************************/
- // --> function llgbo_RenderContent($content,$element_info)
  include_once(LLGBO_PATH.'include/manage_picture_content.php');
-/******************************************************************/		 
-  
+/******************************************************************/		   
 
-
-/******************************************************************/
-function LLGBO_prefilter_Content_Frame($content, $smarty)
-/******************************************************************/
-{  
-// --------------------------------------
-// add  End frame  picture_content TPL
-// --------------------------------------
-  global $themeconf;
-  $search = '{foreach from=$current.unique_derivatives';
-  $replacement = '{$llgbo.FRAME_END}'.'</div>'."\n".' <!-- end LLGBO frame -->'."\n".$search;
-	if (( strpos(strtoupper($themeconf['name']) , 'STRIPPED') === 0) ) 
-		{$search = 'class="hideTabs">';
-		$replacement =  $search
-		.'{$llgbo.FRAME_END}'
-		."</div>";
-		}
-   if (( strpos(strtoupper($themeconf['name']) , 'PWGCARBON_DFT') === 0) ) 
-		{$search = '{if $DISPLAY_NAV_THUMB}';
-		$replacement =   '{$llgbo.FRAME_END}'
-		."</div>"."</div> <!-- end GBO frame -->"
-		.$search;
-		} 
-  $content = str_replace($search, $replacement, $content); 
-  return $content;
-}
-
-
-/******************************************************************/
-function LLGBO_prefilter_Picture_Frame($content, $smarty)
-/******************************************************************/
-{  
-// ------------------------------------
-//  add begin frame on picture TPL
-// --------------------------------------
- $search = '<div id="theImage">';
- $replacement = $search."\n".'{if isset($llgbo.TITLE_FRAME)}'."\n".'<span  id="llgboh2" style ="background:transparent;z-index:3;color:{$llgbo.TITLE_FRAME_COLOR}">{$llgbo.TITLE_FRAME}</span>';
- $replacement = $replacement."\n".'{/if}'."\n".'{$llgbo.FRAME_SIZE}'."\n".'{$llgbo.FRAME_BEGIN}';
-
-// ------------------------
-  return  str_replace($search, $replacement, $content);
-
-}
 /******************************************************************/
 //    trigger à intercepter    
@@ -240,15 +119,11 @@
  add_event_handler('init', 'llgbo_init'); 
 if (defined('IN_ADMIN'))
-{
-  add_event_handler('get_admin_plugin_menu_links', 'llgbo_admin_menu');
+{    add_event_handler('get_admin_plugin_menu_links', 'llgbo_admin_menu'); }
+else
+{   add_event_handler('loc_begin_page_header', 'llgbo_beginheader');
+	add_event_handler('loc_end_page_header', 'llgbo_endHeader');
+	add_event_handler('loc_begin_picture','llgbo_BeginPicture');
+	add_event_handler('loc_end_picture', 'llgbo_EndPicture');
+	add_event_handler('render_element_content', 'llgbo_RenderContent',  EVENT_HANDLER_PRIORITY_NEUTRAL, 20 );
 }
-else
-{                    
-	add_event_handler('loc_begin_page_header', 'llgbo_beginheader');
-	add_event_handler('loc_end_page_header', 'llgbo_endHeader');
-	add_event_handler( 'loc_begin_picture','llgbo_BeginPicture');
-	add_event_handler( 'loc_end_picture', 'llgbo_EndPicture');
-	add_event_handler('render_element_content', 'llgbo_RenderContent',  EVENT_HANDLER_PRIORITY_NEUTRAL-1, 20  );
-}
-
 ?>
Index: extensions/LLGBO2/template/llgbo_content.tpl
===================================================================
--- extensions/LLGBO2/template/llgbo_content.tpl	(revision 29048)
+++ extensions/LLGBO2/template/llgbo_content.tpl	(revision 29049)
@@ -17,7 +17,5 @@
 	{/if}
 
-	{if  isset($llgbo.READIMGREELSIZE)}	
-	<div id="LLGBO_READIMGREELSIZE" style="visibility:hidden;top:0;"> <!--  if exists Force javascript LlgboFr_Resize  to Read MainImage Reel Size via URL" --></div>
-	{/if}
 
 
+

Index: extensions/LLGBO2/include/manage_picture_content.php
===================================================================
--- extensions/LLGBO2/include/manage_picture_content.php	(revision 29048)
+++ extensions/LLGBO2/include/manage_picture_content.php	(revision 29049)
@@ -2,17 +2,14 @@
 function llgbo_RenderContent($content,$element_info)
 /******************************************************************/
-{
-//----------------------------------------------------	 
-/*      LLGBO Manage Picture_content   			   */
-//----------------------------------------------------
+{	//----------------------------------------------------	 
+	/*      LLGBO Manage Picture_content   			   */
+	//----------------------------------------------------
 	global $template,$conf;	
-	 
 	$template->assign('LLGBO_PATH',LLGBO_PATH);
 	include_once(LLGBO_PATH.'/css/sweettitles.css.php');	
-
 	//-----------------------------------------------------------------
 	// -----------  add CSS tooltip in footer --------------------
 	//-----------------------------------------------------------------
-	 If (($conf['LLGBO2']['tooltipdisp']  )  or  ($conf['LLGBO2']['exifunderbt']))    
+	 if (($conf['LLGBO2']['tooltipdisp']  )  or  ($conf['LLGBO2']['exifunderbt']))    
 		{	$template->append('footer_elements',$sweetcss);
 			$template->append('llgbo', array( 'TOOLTIP' => 'ok' ), true);}
@@ -20,31 +17,75 @@
 	// Frame is only available on picture extension	
 	//-----------------------------------------------------------------
-	unset ($conf['LLGBO2']['rendercontent']); 
+	unset ($conf['LLGBO2']['is-picture']); 
 	 $ext = get_extension($element_info['path']);
 	 if (!in_array($ext, $conf['picture_ext'])) 
 				{return $content;}
-		$conf['LLGBO2']['rendercontent'] = true;	// $content ok for update
-		
+				
+	$conf['LLGBO2']['is-picture'] = true;	// $content ok for update
+	$update_tpl = false ;
 	//-----------------------------------------------------------------
 	// AN OTHER PLUGIN IS WORKING -> GO BACK
 	//-----------------------------------------------------------------
 	if ( !empty($content) ) 
-		{	 // 2.6 paticular case automatic size management
-		 $autosize_on = $template->get_template_vars('is_automatic_size');
-		 if (empty($autosize_on) )
-					{return $content;}
-					
+		{	 // 2.6 paticular case automatic size management and Modus
+			 $autosize_on = $template->get_template_vars('is_automatic_size');
+			 $current = $template->get_template_vars('current'); // modus 
+			 if ((empty ($current['selected_derivative'])) and (empty($autosize_on) ))
+						{return $content;}						
+		}
+	//-----------------------------------------------------------------
+	if (($conf['LLGBO2']['frame'])   ) //Frame
+	{ 	$deriv_type = pwg_get_session_var('picture_deriv', $conf['derivative_default_size']);
+		$PictSizeWH =  $element_info['derivatives'][$deriv_type]->get_size();  // default conf
+		
 		$autosize_type = $template->get_template_vars('automatic_size');
-		 unset ($conf['LLGBO2']['PictSizeWH'] );
-		if (isset($autosize_type)) 
-		        	{$conf['LLGBO2']['PictSizeWH'] =  $element_info['derivatives'][$autosize_type]->get_size();
-					 }
-		}
-
+		
+		if (isset($autosize_type)) // auto size
+			{ 	$PictSizeWH =  $element_info['derivatives'][$autosize_type]->get_size(); 
+				$update_tpl = true ;}
+			
+		if (isset($current['selected_derivative'])) // modus
+			{ 	$PictSizeWH =  $current['selected_derivative']->get_size(); 
+				$update_tpl = true ;}
+			
+	// -- Css Theme adaptation
+		$themeconf = $template->get_template_vars('themeconf');
+		if (file_exists(LLGBO_PATH."css/llgbo_content_".$themeconf['id'].".css")) // no css file dedicated for this theme
+			   { $themestyle = $themeconf['id'];}
+			   else
+			   {$themestyle = 'default';}
+	// -- Frame build		
+	        $frame_begin = '';   
+			$frame_border =0;		
+			$frame_end = '</div>'."\n".' <!-- end LLGBO frame -->'."\n";
+			 foreach ($conf['LLGBO2']['FR-sizes'] as $cle  => $value) 
+				{ if ( $value > 0)	// boder value > 0	
+					 {	$frame_border = $frame_border + ( 2 * $value);				 
+						$frame_begin = '<div class="llgboFR" style="border:'.$value.'px solid '.$conf['LLGBO2']['FR-colors'][$cle].'">'."\n".$frame_begin;
+						$frame_end = '</div>'.$frame_end;
+						} 
+				}
+			$frame_begin ="\n".'<!-- Begin LLGBO frame -->'."\n".$frame_begin;
+			$PictSizeWH[0] = $PictSizeWH[0] + $frame_border;
+			$PictSizeWH[1] = $PictSizeWH[1] + $frame_border;
+			$frame_size = "\n".'<div   id="llgbo0" class="llgbo" style="border:0 ;width:'.$PictSizeWH[0].'px; height:'.$PictSizeWH[1].'px;">';
+	
+			if ($conf['LLGBO2']['titleframe']) {
+				$frame_title =  "\n".'<!-- Begin LLGBO -->'."\n".'<span  id="llgboh2" style ="background:transparent;z-index:3;color:'.$conf['LLGBO2']['FR-titlecolor'].'">'.$element_info['name'].'</span>';	
+				}
+			
+			$template->append('llgbo', array(   
+							'FRAME_TITLE' => $frame_title,
+							'FRAME_SIZE' => $frame_size ,
+							'FRAME_BEGIN' => $frame_begin,
+							'FRAME_END' => $frame_end,
+							 'GBOCSS' => LLGBO_PATH."css/llgbo_content_".$themestyle.".css" ), true); 
+							 
+			$template->set_prefilter('default_content', 'LLGBO_prefilter_Content_Frame');								 
+	} // end frame					
 //----------------------------------------------------	 
 //-------      Tooltip                   -------------	 
 //----------------------------------------------------
-	 
-	If ($conf['LLGBO2']['tooltipdisp'] )//   tooltip  
+	if ($conf['LLGBO2']['tooltipdisp'] )//   tooltip  
 	{  	$prev = $template->get_template_vars('previous');
 		$next  = $template->get_template_vars('next');
@@ -53,37 +94,20 @@
 		if (isset($next)){$template->append('next',  array('TITLE_ESC' =>  $next['TITLE_ESC'].$swtimg.$next['THUMB_SRC'].'>'),TRUE);}
 		$template->append('llgbo', array('tooltipCSS'  => $sweetcss), true); 
-	}	
-	
-	If (($conf['LLGBO2']['frame'])   ) //Frame
-	{ 	$template->set_prefilter('default_content', 'LLGBO_prefilter_Content_Frame');
-	//----------------------------------------------------	 
-	/*       HTML End  frame   on Picture_content       */
-	//----------------------------------------------------		
-		$csstheme = 'default';
-		$themeconf = $template->get_template_vars('themeconf');
-		//  dedicated Css by parent theme	
-			if (isset ($themeconf['parent']))
-			{ $themestyle = $themeconf['parent'];}
-			If (file_exists(LLGBO_PATH."css/llgbo_content_".$themeconf['id'].".css")) // no css file dedicated for this theme
-			   { $themestyle = $themeconf['id'];}
-			   else
-			   {$themestyle = 'default';}
-			   $frame_end = '';
-			   
-			 foreach ($conf['LLGBO2']['FR-sizes'] as  $value) 
-				{if ( $value > 0)	// boder value > 0	
-					{	$frame_end = $frame_end.'</div>';}
-				 }
-			 
-			 $template->append('llgbo', array(
-				'FRAME_END' => $frame_end,
-				'GBOCSS' => LLGBO_PATH."css/llgbo_content_".$themestyle.".css" ), true); 
-
-	} // end frame
-	 // 2.6 paticular case automatic size management
-	if ((isset($autosize_on))  and  (isset ($autosize_type)) )
-						{ return $template->parse( 'default_content', true);}
+	}	 	 
+	 // 2.6 paticular case automatic size and modus management
+	if ($update_tpl) 
+		{return $template->parse( 'default_content', true);}  
 						
 } //end --> llgbo_RenderContent
 
+/******************************************************************/
+function LLGBO_prefilter_Content_Frame($content, $smarty)
+/******************************************************************/
+{ 	 // add  frame on picture_content TPL
+	// --------------------------------------   
+		$patern = '/'.'<img(.*)id="theMainImage"(.*)>'.'/';	
+        $replacement =  $replacement.'{$llgbo.FRAME_TITLE}'.'{$llgbo.FRAME_SIZE}'.'{$llgbo.FRAME_BEGIN}'."\n".'<img $1 id="theMainImage" $2> '.'{$llgbo.FRAME_END}';
+		$content = preg_replace($patern, $replacement, $content);  
+        return $content;
+}
 ?>